@@ -6,7 +6,7 @@ ALPHABET_6 = {
     "####\n#...\n###.\n#...\n#...\n#...": "F",
     ".##.\n#..#\n#...\n#.##\n#..#\n.###": "G",
     "#..#\n#..#\n####\n#..#\n#..#\n#..#": "H",
-    "###\n.#.\n.#.\n.#.\n.#.\n###": "I",
+    ".###\n..#.\n..#.\n..#.\n..#.\n.###": "I",
     "..##\n...#\n...#\n...#\n#..#\n.##.": "J",
     "#..#\n#.#.\n##..\n#.#.\n#.#.\n#..#": "K",
     "#...\n#...\n#...\n#...\n#...\n####": "L",
@@ -15,6 +15,6 @@ ALPHABET_6 = {
     "###.\n#..#\n#..#\n###.\n#.#.\n#..#": "R",
     ".###\n#...\n#...\n.##.\n...#\n###.": "S",
     "#..#\n#..#\n#..#\n#..#\n#..#\n.##.": "U",
-    "#...#\n#...#\n.#.#.\n..#..\n..#..\n..#..": "Y",
+    "#...\n#...\n.#.#\n..#.\n..#.\n..#.": "Y",
     "####\n...#\n..#.\n.#..\n#...\n####": "Z",
 }
